# -*- coding: utf-8 -*-

# This file is subject to the terms and conditions defined in
# file 'LICENSE', which is part of this source code package.
#       Copyright (c) 2011 R Pratap Chakravarthy

"""Package directory contain plugins implementing 
:class:`tayra.interfaces.ITayraFilterBlock` interface specification."""

import tayra.filterblocks.pycode
